%% used in version 1, submitted to JCP on March 29
figure('Position', [100 100 560 620]);
label = {'(a)';'(b)';'(c)';'(d)';'(e)';'(f)'};

%% CDF, all densities
subplot(3,2,1);

rhos = 0.03:0.01:0.12;
n = length(rhos);

path = sprintf("../cdf/rho_dependence");
c = 0:1/n:1;

x = 0:1999;
for i = 1:n
    filename = sprintf("%s/cdf_%g.dat", path, rhos(i));
    fid = fopen(filename);
    X = textscan(fid, '%f', 'HeaderLines', 1);
    y = X{1};
    fclose(fid);
    plot(x, y*1000, 'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{1}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0 100 200 300 400]);
yticks([0 0.4 0.8]);
xlim([1, 400]);
ylim([0, 0.8]);
xlabel('$s$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$s\Pi(s)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Distribution Function in SALR');

%% CDF, all temperatures
subplot(3,2,2);

T = 0.5:0.05:0.85;
rho = 0.1;
n = length(T);
path = sprintf("../cdf/T_dependence");

c = 0:1/n:1;

x = 0:1999;
for i = 1:n
    filename = sprintf("%s/cdf_T%g.dat", path, T(i));
    fid = fopen(filename);
    X = textscan(fid, '%f', 'HeaderLines', 1);
    y = X{1};
    fclose(fid);
    plot(x, y*1000, 'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{2}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0 100 200 300 400]);
yticks([0 0.4 0.8]);
xlim([1, 400]);
ylim([0, 0.8]);
xlabel('$s$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$s\Pi(s)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Distribution Function in SALR');

%% W(n), all densities
subplot(3,2,3);

rhos = 0.03:0.01:0.12;
n = length(rhos);
path = sprintf("../cdf/rho_dependence");
c = 0:1/n:1;

x = 0:1999;
for i = 1:n
    filename = sprintf("%s/cdf_%g.dat", path, rhos(i));
    fid = fopen(filename);
    X = textscan(fid, '%f', 'HeaderLines', 1);
    y = X{1};
    fclose(fid);
    
    y(2:end) = y(2:end) / sum(y(2:end));
    y(2:200) = log(y(2:200));
    y(2:200) = y(2:200) - y(2);
    plot(x(2:200), -0.55 * y(2:200),  'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{3}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
yticks([0 2 4 6]);
xlim([1, 100]);
ylim([0, 6]);
xlabel('$s$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$F(s)/k_B$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Formation Free Energies in SALR');

%% W(n), all temperatures
subplot(3,2,4);

T = 0.5:0.05:0.85;
rho = 0.1;
n = length(T);
path = sprintf("../cdf/T_dependence");

c = 0:1/n:1;

x = 0:1999;
for i = 1:n
    filename = sprintf("%s/cdf_T%g.dat", path, T(i));
    fid = fopen(filename);
    X = textscan(fid, '%f', 'HeaderLines', 1);
    y = X{1};
    fclose(fid);
    
    y(2:end) = y(2:end) * 2000;
    y(2:end) = y(2:end) ./ (x(2:end)') * 2000;
    y(2:200) = log(y(2:200));
    y(2:200) = y(2:200) - y(2);
    plot(x(2:200), -T(i) * y(2:200),  'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{4}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xlim([1, 100]);
xlabel('$s$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$F(s)/k_B$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Formation Free Energies in SALR');

%% CADF, all densities
subplot(3,2,5);

T = 0.55;
rhos = 0.03:0.01:0.12;
n = length(rhos);
path = sprintf("../cadf/rho_dependence");
c = 0:1/n:1;

for i = 1:n
    filename = sprintf("%s/cadf_%g.dat", path, rhos(i));
    fid = fopen(filename);
    X = textscan(fid, '%f %f', 'HeaderLines', 1);
    x = X{1};
    y = X{2};
    fclose(fid);
    
    ratio = sum(y);
    fprintf("%f, %f\n", rhos(i), ratio);
    plot(x, y, 'color',[c(i), 0, c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{5}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0 0.1 0.2 0.3 0.4 0.5]);
xlim([0, 0.5]);
ylim([0, 0.05]);
xlabel('$\gamma$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$\mathcal{P}(\gamma)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Anisotropy Distribution in SALR');

%% CADF, all temperatures
subplot(3,2,6);

T = 0.5:0.05:0.85;
rho = 0.1;
n = length(T);
path = sprintf("../cadf/T_dependence");
c = 0:1/n:1;

for i = 1:n
    filename = sprintf("%s/cadf_T%g.dat", path, T(i));
    fid = fopen(filename);
    X = textscan(fid, '%f %f', 'HeaderLines', 1);
    x = X{1};
    y = X{2};
    fclose(fid);
    ratio = sum(y);
    plot(x, y./ratio, 'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{6}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0 0.1 0.2 0.3 0.4 0.5]);
xlim([0, 0.5]);
ylim([0, 0.05]);
xlabel('$\gamma$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$\mathcal{P}(\gamma)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Cluster Anisotropy Distribution in SALR');
