%% plot: h(rho) - various temperature
% [1, 1.5, 4, 1, 0.025]

T = 0.5:0.05:0.9;
n = length(T);
c = 0:1/n:1;

% critical cluster densities
x = [0.0041891, 0.008228, 0.014023, 0.022634, 0.030786, 0.036089, 0.037447, 0.035278];
y = [-113.289375, -56.867379, -32.349387, -20.003481, -13.212272, -9.453792, -7.104180, -5.593803];

% virial coefficients
b2 = [-23.493442, -17.933354, -14.085382, -11.307455, -9.232663, -7.639175, -6.386500, -5.382147];
b3 = [-885.786790, -387.726618, -178.031713, -82.235802, -35.862047, -12.545452, -0.604875, 5.479364];
b4_1 = [-67390.759943, -26310.242660, -11558.569502, -5570.550810, -2893.137699, -1598.793954, -931.492350, -5.683728e+02];
b4_2 = [-101945.248363, -23638.209569, -5187.006211, -572.640835, 504.000099, 644.276261, 555.302873, 4.327440e+02];
b4_3 = [7.850650e+03, 4.825149e+03, 2.343017e+03, 1.122003e+03, 5.521006e+02, 2.812896e+02, 1.480987e+02, 8.014228e+01];
b4 = ones(length(b4_1),1);
for i = 1:length(b4_1)
    b4(i) = b4_1(i) + b4_2(i) + b4_3(i);
end
 
color = get(gca,'colororder');

path = "../h_rho";

for i = 1:n-1
    filename = sprintf("%s/1,1.5,4,1,0.025_T%g.dat", path, T(i));
    fid = fopen(filename);
    X1 = textscan(fid, '%f %f %f %f %f %f', 'HeaderLines', 1);
    T1 = X1{1}(1);
    rho1 = X1{2};
    p1 = X1{3};  %ecmc
    p11 = X1{4};
    err = X1{5};
    h1 = (p1/T1 - rho1) ./ (rho1.^2);
    h11 = (p11/T1 - rho1) ./ (rho1.^2);
    fclose(fid);
    rho2 = logspace(-3, log10(x(i) * T(i) * 1.5),10);
    if i == n-1
        rho2 = logspace(-3, log10(x(n-1) * T(n-1) * 1.9),10);
    end
    h2 = b2(i) + rho2 * b3(i) + rho2.^2 * b4(i);
    
    loglog(rho1, h1,  'color', [c(i),0,c(n+1-i)], 'linewidth',1.5), hold on;
    loglog(x(i),y(i), '.', 'color', [c(i),0,c(n+1-i)],'linewidth',1.5, 'MarkerSize', 18), hold on;
    loglog(rho2, h2, '--', 'color', [c(i),0,c(n+1-i)],'linewidth',1.5), hold on;
    %plot(x, y, 'color',[c(i),c(n+1-i),0], 'linewidth',1), hold on;
    %plot(x, y, 'color',[c(i),c(i)/2,c(n+1-i)], 'linewidth',1), hold on;
end

filename = sprintf("%s/1,1.5,4,1,0.025_T0.9.dat", path);
fid = fopen(filename);
X1 = textscan(fid, '%f %f %f %f %f %f', 'HeaderLines', 1);
T1 = X1{1}(1);
rho1 = X1{2};
p1 = X1{3};  %ecmc
h1 = (p1/T1 - rho1) ./ (rho1.^2);
fclose(fid);
rho2 = logspace(-3, log10(0.1),100);
b2 = -4.563183;
b3 = 8.454810;
b4 = -3.614483e+02 + 3.264469e+02 + 4.425213e+01;
h2 = b2 + rho2 * b3 + rho2 .^ 2 * b4;
loglog(rho1, h1,  'color', [c(n),0,c(n+1-n)], 'linewidth',1.5), hold on;
loglog(rho2, h2, '--', 'color', [c(n),0,c(n+1-n)], 'linewidth',1.5), hold on;    
    

filename = sprintf("%s/1,1.5,4,1,0.025_T1.dat", path);
fid = fopen(filename);
X1 = textscan(fid, '%f %f %f %f %f %f', 'HeaderLines', 1);
T1 = X1{1}(1);
rho1 = X1{2};
p1 = X1{3};  %ecmc
h1 = (p1/T1 - rho1) ./ (rho1.^2);
fclose(fid);
rho2 = logspace(-3, log10(0.5),100);
b2 = -3.317695;
b3 = 10.123910;
b4 = -1.632934e+02 + 1.836995e+02;
h2 = b2 + rho2 * b3;% + rho2 .^ 2 * b4;
loglog(rho1, h1,  'k', 'linewidth',1.5), hold on;
loglog(rho2, h2, 'k--','linewidth',1.5), hold on;

set(gcf,'Position',[100 100 560 420]);
set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
set(gca, 'DefaultLineLineWidth', 1.5);
%legend('T=0.5', 'T=0.55', 'T=0.6', 'T=0.65', 'T=0.7', 'T=0.75', 'T=0.8', 'Location', 'southeast');
xlim([0, 0.2]);
ylim([-2e2, -1e0]);
xlabel('$\rho$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$h(\rho)$', 'Interpreter', 'Latex', 'fontsize',16);

text(-0.12, 1, "(a)", 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
