% combination of two percolation figures, T = 0.9
addpath(genpath('..'));

figure('Position', [100 100 560 210]);
label = {'(a)';'(b)'};

%% left: percolation probability - density for varying N
subplot(1,2,1);

T = 0.9;
N = [250, 500, 1000];
n = length(N);

path = "../percolation/particles";
output = sprintf("percolation_3d_T%g.dat", T);
color = get(gca,'colororder');
str = [];

for i = 1:n
    filename = sprintf("%s/N%g/%s", path, N(i), output);
    fid = fopen(filename);
    X1 = textscan(fid, '%f %f %f %f', 'HeaderLines', 1);
    fclose(fid);
       
    x1 = X1{2};
    y1 = X1{3};
    
    plot(x1, y1, '-o', 'color', color(i,:)', 'linewidth',1), hold on;
    str = [str, sprintf("N%g", N(i))];
end

x = linspace(0.1, 0.28, 10);
plot(x, ones(length(x),1).*0.5, 'k--', 'linewidth',1);

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.25, 1, label{1}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0.16 0.2 0.24 0.28]);

%legend(str, 'Location', 'southeast', 'fontsize',12);
%legend boxoff;
xlim([0.16, 0.28]);
ylim([0, 1]);
xlabel('$\rho$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$p_p(\rho)$', 'Interpreter', 'Latex', 'fontsize',16);

%% rhoc - N: for low T
%  fitting with largest three system sizes N
subplot(1,2,2);

T = 0.9;
color = get(gca,'colororder');

fid = fopen(sprintf("../percolation/particles/rhoc_N_T%g.dat", T));
X1 = textscan(fid, '%f \t %f \t %f', 'HeaderLines', 1);
N = X1{1};
T = X1{2}(1);
rhoc = X1{3};
fclose(fid);

dv = 2.706;
N = flip(N);
rhoc = flip(rhoc);
[p,S] = polyfit(N(1:3).^(-1/ dv), rhoc(1:3), 1);
[y, err] = polyval(p, 0, S);
% t-distribution: tinv(percentile, degree of freedom)
fprintf("%g \t %f \t %e \n", T, p(2), err / sqrt(length(N)) * tinv(0.95,2));

plot(N(1:3).^(-1/dv), rhoc(1:3), 'o', 'color', color(1,:)', 'linewidth',1), hold on;
%plot(N(4:5).^(-1/dv), rhoc(4:5), 'o', 'color', color(1,:)', 'linewidth',1), hold on;
x = linspace(0, N(end).^(-1/dv), 10);
plot(x, polyval(p, x), '--', 'color', color(2,:)', 'linewidth',1), hold on;
plot(0, p(2), '.', 'MarkerSize',16, 'color', color(2,:)');

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.28, 1, label{2}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
ylim([0.18, 0.22]);
%yticks([0.13 0.15 0.17 0.19]);

xlabel('$N^{-1/d\nu}$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$\rho_c$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Percolation Threshold for Several System Size in SALR');