% draw thermodynamic properties of void clusters

addpath(genpath('..'));

figure('Position', [100 100 560 190]);
label = {'(a)';'(b)'};

%% left: VCDF for all densities
subplot(1,2,1);

T = 0.6;
%rhos = 0.4;
rhos = 0.58:0.02:0.68;
n = length(rhos);
path = sprintf("../vcdf");
c = 0:1/n:1;

for i = 1:n
    filename = sprintf("%s/vcdf_%g.dat", path, rhos(i));
    fid = fopen(filename);
    if fid == -1
        continue
    end
    X = textscan(fid, '%f \t %f', 'HeaderLines', 1);
    fclose(fid);
    x = X{1};
    y = X{2};
    x = x * 0.5^3;
    y = y .* x;
    z = sortrows([x y],1);
    z = vcdf_average(z, 40);
    plot(z(:,1), z(:,2), 'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
end

set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.28, 1, label{1}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');

xlim([0, 250]);
ylim([0, 0.08]);
xlabel('$v$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$v\Pi(v)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Void Cluster Distribution Function in SALR');

%% VADF, all densities
subplot(1,2,2);

T = 0.6;
rhos = 0.58:0.02:0.68;
n = length(rhos);
path = sprintf("../vadf");
c = 0:1/n:1;

%output = sprintf("cadf_T%g.dat", T);
%fid2 = fopen(output, "a");
%fprintf(fid2, "rho \t Apeak1 \t Apeak2\n");

for i = 1:n
    filename = sprintf("%s/vadf_%g.dat", path, rhos(i));
    fid = fopen(filename);
    if fid == -1
        continue
    end
    X = textscan(fid, '%f %f', 'HeaderLines', 1);
    x0 = X{1};
    y0 = X{2};
    fclose(fid);
    % output the area of two peaks
    %fprintf(fid2, "%g \t %.6f \t %.6f\n", rhos(i), sum(y(1:34)), sum(y(35:end)));
    
    x = x0(1:end-100);
    y = y0(1:end-100);
    y(96:100) = 0;
    
    ratio = sum(y);
    fprintf("%f, %f\n", rhos(i), ratio);
    plot(x, y./ratio, 'color',[c(i),0,c(n+1-i)], 'linewidth',1), hold on;
    %plot(x, y, 'color',[c(i),c(i)/2,c(n+1-i)], 'linewidth',1), hold on;
end

%fclose(fid2);
set(gca,'fontsize',14);
set(gca,'fontname','Times New Roman');
text(-0.28, 1, label{2}, 'Units','normalized', 'fontname','Times New Roman', 'FontSize',16, 'color','k');
xticks([0 0.1 0.2 0.3 0.4 0.5]);
yticks([0 0.01 0.02 0.03 0.04]);

xlim([0, 0.5]);
ylim([0, 0.04]);
xlabel('$\gamma$', 'Interpreter', 'Latex', 'fontsize',16);
ylabel('$\mathcal{P}(\gamma)$', 'Interpreter', 'Latex', 'fontsize',16);
%title('Void Anisotropy Distribution in SALR');

