%% create a .dat file
fid2 = fopen(sprintf("rhoc_thermo_N.dat", T), "a");
fprintf(fid2, 'T \t rhoc \t err \n');
fclose(fid2);

%% rhoc - N: for low T
%  fitting with largest three system sizes N

T = 0.8;
color = get(gca,'colororder');

fid = fopen(sprintf("./rhoc_N_T%g.dat", T));
X1 = textscan(fid, '%f \t %f \t %f', 'HeaderLines', 1);
N = X1{1};
T = X1{2}(1);
rhoc = X1{3};
fclose(fid);

dv = 2.706;
N = flip(N);
rhoc = flip(rhoc);
[p,S] = polyfit(N(1:3).^(-1/ dv), rhoc(1:3), 1);
[y, err] = polyval(p, 0, S);
% t-distribution: tinv(percentile, degree of freedom)
fprintf("%g \t %f \t %e \n", T, p(2), err / sqrt(length(N)) * tinv(0.95,2));

% write the data
%fid2 = fopen(sprintf("rhoc_thermo_N.dat", T), "a");
%fprintf(fid2, "%g \t %f \t %e \n", T, p(2), err / sqrt(length(N)) * tinv(0.95,2));
%fclose(fid2);

plot(N(1:3).^(-1/dv), rhoc(1:3), 'o', 'color', color(1,:)', 'linewidth',1), hold on;
plot(N(4:5).^(-1/dv), rhoc(4:5), 'o', 'color', color(1,:)', 'linewidth',1), hold on;
x = linspace(0, N(5).^(-1/dv), 10);
plot(x, polyval(p, x), '--', 'color', color(2,:)', 'linewidth',1), hold on;
plot(0, p(2), '.', 'MarkerSize',16, 'color', color(2,:)');
%ylim([0, 1]);
xlabel('$N^{-1/d\nu}$', 'Interpreter', 'Latex', 'fontsize',14);
ylabel('$\rho_c$', 'Interpreter', 'Latex', 'fontsize',14);
%title('Percolation Threshold for Several System Size in SALR');


%% rhoc - N: for high T
%  fitting with three or four points

T = 0.8;
color = get(gca,'colororder');

fid = fopen(sprintf("./rhoc_N_T%g.dat", T));
X1 = textscan(fid, '%f \t %f \t %f', 'HeaderLines', 1);
N = X1{1};
T = X1{2}(1);
rhoc = X1{3};
fclose(fid);

dv = 2.706;
N = flip(N);
rhoc = flip(rhoc);
[p,S] = polyfit(N.^(-1/ dv), rhoc, 1);
[y, err] = polyval(p, 0, S);
% t-distribution: tinv(percentile, degree of freedom)
fprintf("%g \t %f \t %e \n", T, p(2), err / sqrt(length(N)) * tinv(0.95,2));

% write the data
%fid2 = fopen(sprintf("rhoc_thermo_N.dat", T), "a");
%fprintf(fid2, "%g \t %f \t %e \n", T, p(2), err / sqrt(length(N)) * tinv(0.95,2));
%fclose(fid2);

plot(N.^(-1/dv), rhoc, 'o', 'linewidth',1), hold on;
x = linspace(0, N(end).^(-1/dv), 10);
plot(x, polyval(p, x), '--', 'linewidth',1), hold on;
plot(0, p(2), '.', 'MarkerSize',16, 'color', color(2,:)');
%ylim([0, 1]);
xlabel('$N^{-1/d\nu}$', 'Interpreter', 'Latex', 'fontsize',14);
ylabel('$\rho_c$', 'Interpreter', 'Latex', 'fontsize',14);
%title('Percolation Threshold for Several System Size in SALR');

